==> haskell-gtk-sni-tray-0.1.8.1-306-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-HdO2aVrSUFl6g0tFFfkFAM
key:                    gtk-sni-tray-0.1.8.1-HdO2aVrSUFl6g0tFFfkFAM
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    028767b1ec23da35212bf8f0f06f71f5
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-HdO2aVrSUFl6g0tFFfkFAM
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype bz2
    png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-HjMuQpYyQPjHxd2qGwYnY9 directory-1.3.7.1
    enclosed-exceptions-1.0.3-HM6uFoQdyYA6AHlPbiqg1l filepath-1.4.2.2
    gi-cairo-1.0.29-Cwan3gl5Ulk2aSlu0XNlMk
    gi-cairo-connector-0.1.1-E74rDy9KZeKB8xHh8vcPKQ
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    gi-dbusmenugtk3-0.4.15-GJnxX1BwJKf8dfIpXEB9QA
    gi-gdk-3.0.28-1X26bC7pZWw4P2pKxfXJVN
    gi-gdkpixbuf-2.0.32-JlXBlJbnsJd1Chf8ZYqJAC
    gi-glib-2.0.29-J16swKV2VKe8h4nbkTUgoE
    gi-gtk-3.0.39-71wegpXxZREYUeF0azH5H
    gtk-strut-0.1.3.2-1uRPSBz6I1hL3wlNkWmnYL
    haskell-gi-0.26.14-IrBjLS40w2kJHbVqEUJV06
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.1.2-FC7vxUknfc9IVyZkGgrnoC
    status-notifier-item-0.3.1.0-AOKI2Awx7Oz4yivTcT6Si6 text-2.0.2
    transformers-0.5.6.2 transformers-base-0.4.6-ChRW239HasyDHet7IIm2Fi
    unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-sni-tray-0.1.8.1-307-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-6FCys1tp84321m0HGlGxz0
key:                    gtk-sni-tray-0.1.8.1-6FCys1tp84321m0HGlGxz0
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    ab9d9e193c756c4a28b66a9822d93fe0
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-6FCys1tp84321m0HGlGxz0
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype bz2
    png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-GX05K6LrdV99o0sz1bmo1V directory-1.3.7.1
    enclosed-exceptions-1.0.3-6hi1MN9omrXLmJjVfHd2DP filepath-1.4.2.2
    gi-cairo-1.0.29-263gvTh2qqtEAOebDdnMD7
    gi-cairo-connector-0.1.1-C9UMdiWFds2AjSZBPTTxwn
    gi-cairo-render-0.1.2-Cu8qroZ3YG62utUD4ndmUZ
    gi-dbusmenugtk3-0.4.15-HCqKruHAuuiKmwS6AT9MUe
    gi-gdk-3.0.28-7bGkfNem7BRGFfjI0Oirha
    gi-gdkpixbuf-2.0.32-EybHDXPhg96LZKMeLBddjI
    gi-glib-2.0.29-49hBCX92oakJYox4t2nUnx
    gi-gtk-3.0.39-FvQy4vq0Bmf8XJKb0FxXXB
    gtk-strut-0.1.3.2-7rcMilw2RmT5kT70UWpIv6
    haskell-gi-0.26.14-DpfgOMXczb8CuQSzylwdXN
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.1.2-3HAaxPHRVNmEtghEgAUY69
    status-notifier-item-0.3.1.0-DppoNZnOtLq64LDFMyLCWA text-2.0.2
    transformers-0.5.6.2 transformers-base-0.4.6-8n2vEXi35k9DcuZkJZ3K5I
    unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
